@@ -5,7 +5,7 @@ author = {
 	"email":"maloja@dev.krateng.ch",
 	"github": "krateng"
 }
-version = 2,12,16
+version = 2,13,4
 versionstr = ".".join(str(n) for n in version)
 links = {
 	"pypi":"malojaserver",
@@ -15,7 +15,7 @@ python_version = ">=3.6"
 requires = [
 	"bottle>=0.12.16",
 	"waitress>=1.3",
-	"doreah>=1.6.12",
+	"doreah>=1.7.1",
 	"nimrodel>=0.7.0",
 	"setproctitle>=1.1.10",
 	"wand>=0.5.4",
@@ -28,8 +28,11 @@ resources = [
 	"web/*/*",
 	"web/*",
 	"data_files/*/*",
+	"data_files/*/.*",
 	"data_files/*/*/*",
+	"data_files/*/*/.*",
 	"data_files/*/*/*/*",
+	"data_files/*/*/*/.*",
 	"*/*.py",
 	"*/*/*.py",
 	"*/*/*/*.py"
